aboutsummaryrefslogtreecommitdiff
path: root/toys/pending
diff options
context:
space:
mode:
authorElliott Hughes <enh@google.com>2019-02-22 19:37:24 -0800
committerRob Landley <rob@landley.net>2019-02-23 08:27:32 -0600
commit42af2e52e771dd7bf8be6fd1119520d492bb4b3f (patch)
tree313385b3e7ac5f05f698d007162242ecc27c1927 /toys/pending
parentaa5ddae1bae1b0cfdef15c3c1cd20b4cee97c182 (diff)
downloadtoybox-42af2e52e771dd7bf8be6fd1119520d492bb4b3f.tar.gz
Bumper typo cleanup.
Inspired by some of the small patches that have gone by recently. Limited to only things found in `generated/help.h`, plus a wider cleanup for the more common "milisecond" typo.
Diffstat (limited to 'toys/pending')
-rw-r--r--toys/pending/dhcp.c2
-rw-r--r--toys/pending/dhcp6.c4
-rw-r--r--toys/pending/fsck.c6
-rw-r--r--toys/pending/host.c2
-rw-r--r--toys/pending/more.c4
-rw-r--r--toys/pending/traceroute.c8
6 files changed, 13 insertions, 13 deletions
diff --git a/toys/pending/dhcp.c b/toys/pending/dhcp.c
index d1f8e801..2dd392dc 100644
--- a/toys/pending/dhcp.c
+++ b/toys/pending/dhcp.c
@@ -13,7 +13,7 @@ config DHCP
usage: dhcp [-fbnqvoCRB] [-i IFACE] [-r IP] [-s PROG] [-p PIDFILE]
[-H HOSTNAME] [-V VENDOR] [-x OPT:VAL] [-O OPT]
- Configure network dynamicaly using DHCP.
+ Configure network dynamically using DHCP.
-i Interface to use (default eth0)
-p Create pidfile
diff --git a/toys/pending/dhcp6.c b/toys/pending/dhcp6.c
index 18aee8a3..c69c4aed 100644
--- a/toys/pending/dhcp6.c
+++ b/toys/pending/dhcp6.c
@@ -11,11 +11,11 @@ config DHCP6
help
usage: dhcp6 [-fbnqvR] [-i IFACE] [-r IP] [-s PROG] [-p PIDFILE]
- Configure network dynamicaly using DHCP.
+ Configure network dynamically using DHCP.
-i Interface to use (default eth0)
-p Create pidfile
- -s Run PROG at DHCP events
+ -s Run PROG at DHCP events
-t Send up to N Solicit packets
-T Pause between packets (default 3 seconds)
-A Wait N seconds after failure (default 20)
diff --git a/toys/pending/fsck.c b/toys/pending/fsck.c
index ac00bff7..ea7c59cd 100644
--- a/toys/pending/fsck.c
+++ b/toys/pending/fsck.c
@@ -9,8 +9,8 @@ config FSCK
bool "fsck"
default n
help
- usage: fsck [-ANPRTV] [-C FD] [-t FSTYPE] [FS_OPTS] [BLOCKDEV]...
-
+ usage: fsck [-ANPRTV] [-C FD] [-t FSTYPE] [FS_OPTS] [BLOCKDEV]...
+
Check and repair filesystems
-A Walk /etc/fstab and check all filesystems
@@ -19,7 +19,7 @@ config FSCK
-R With -A, skip the root filesystem
-T Don't show title on startup
-V Verbose
- -C n Write status information to specified filedescriptor
+ -C n Write status information to specified file descriptor
-t TYPE List of filesystem types to check
*/
diff --git a/toys/pending/host.c b/toys/pending/host.c
index 5e3edd87..dea97b13 100644
--- a/toys/pending/host.c
+++ b/toys/pending/host.c
@@ -13,7 +13,7 @@ config HOST
usage: host [-av] [-t TYPE] NAME [SERVER]
Perform DNS lookup on NAME, which can be a domain name to lookup,
- or an ipv4 dotted or ipv6 colon seprated address to reverse lookup.
+ or an IPv4 dotted or IPv6 colon-seperated address to reverse lookup.
SERVER (if present) is the DNS server to use.
-a no idea
diff --git a/toys/pending/traceroute.c b/toys/pending/traceroute.c
index 9a818eb4..d5ead9e2 100644
--- a/toys/pending/traceroute.c
+++ b/toys/pending/traceroute.c
@@ -15,13 +15,13 @@ config TRACEROUTE
help
usage: traceroute [-46FUIldnvr] [-f 1ST_TTL] [-m MAXTTL] [-p PORT] [-q PROBES]
[-s SRC_IP] [-t TOS] [-w WAIT_SEC] [-g GATEWAY] [-i IFACE] [-z PAUSE_MSEC] HOST [BYTES]
-
- traceroute6 [-dnrv] [-m MAXTTL] [-p PORT] [-q PROBES][-s SRC_IP] [-t TOS] [-w WAIT_SEC]
+
+ traceroute6 [-dnrv] [-m MAXTTL] [-p PORT] [-q PROBES][-s SRC_IP] [-t TOS] [-w WAIT_SEC]
[-i IFACE] HOST [BYTES]
Trace the route to HOST
- -4,-6 Force IP or IPv6 name resolution
+ -4,-6 Force IP or IPv6 name resolution
-F Set the don't fragment bit (supports IPV4 only)
-U Use UDP datagrams instead of ICMP ECHO (supports IPV4 only)
-I Use ICMP ECHO instead of UDP datagrams (supports IPV4 only)
@@ -37,7 +37,7 @@ config TRACEROUTE
-t Type-of-service in probe packets (default 0)(RANGE 0 to 255)
-w Time in seconds to wait for a response (default 3)(RANGE 0 to 86400)
-g Loose source route gateway (8 max) (supports IPV4 only)
- -z Pause Time in milisec (default 0)(RANGE 0 to 86400) (supports IPV4 only)
+ -z Pause Time in ms (default 0)(RANGE 0 to 86400) (supports IPV4 only)
-f Start from the 1ST_TTL hop (instead from 1)(RANGE 1 to 255) (supports IPV4 only)
-i Specify a network interface to operate with
*/
diff --git a/toys/pending/more.c b/toys/pending/more.c
index fa96d40e..79bb7bf9 100644
--- a/toys/pending/more.c
+++ b/toys/pending/more.c
@@ -1,4 +1,4 @@
/* more.c - View FILE (or stdin) one screenful at a time.
*
* Copyright 2013 Bilal Qureshi <bilal.jmi@gmail.com>
*
@@ -12,7 +12,7 @@ config MORE
help
usage: more [FILE...]
- View FILE(s) (or stdin) one screenful at a time.
+ View FILE(s) (or stdin) one screenfull at a time.
*/
#define FOR_more
@@ -1,4 +1,4 @@
-/* more.c - View FILE (or stdin) one screenful at a time.
+/* more.c - View FILE (or stdin) one screenfull at a time.
*
* Copyright 2013 Bilal Qureshi <bilal.jmi@gmail.com>